# DSpace directory structure

This is the directory structure 

```
├── clarin-dspace-docker
│   └── commul-customization
└── kubernetes
    ├── helm
    │   └── dspace
    │       ├── charts
    │       │   └── postgresql
    │       │       └── templates
    │       └── templates
    └── yaml
```


* `/clarin-dspace-docker` - Docker files, copied from https://github.com/commul/clarin-dspace-docker @ 74d06d3
* `/kubernetes` - Kubernetes files
* `/kubernetes/helm` - Chart Directory. Refer to https://github.com/kubernetes/helm/blob/master/docs/charts.md#the-chart-file-structure 
* `/kubernetes/yaml` - Useful for tests, but helm is a more flexible approach
# Introduction
# Prerequisites

* Kubernetes cluster

## To interact with cluster

* Kubernetes credentials
* a working [kubectl] (https://kubernetes.io/docs/tasks/tools/install-kubectl/)

## To interact with Helm server (tiller)

* Kubernetes credentials
* a working [kubectl] (https://kubernetes.io/docs/tasks/tools/install-kubectl/)
* a working [helm client] (https://docs.helm.sh/using_helm/#quickstart-guide)

# How to use it
## Workflow
First of all, check if a docker image already exists.
If it exist, pull, otherwise, you need to build one.
If necessary create a [personal token](https://gitlab.scientificnet.org/profile/personal_access_tokens) and login into GitLab Registry.

```console
docker login gitlab.scientificnet.org:4567
```
 
### Use existing Docker image
```console
docker image ls -a gitlab.scientificnet.org:4567/commul/dspace/*
docker pull gitlab.scientificnet.org:4567/commul/dspace/<my_image>:<my tag>
```

### Build images
* build your docker image from `/clarin-dspace-docker` directory
* push to `https://gitlab.scientificnet.org/commul/dspace/container_registry` 

```console
docker build -t gitlab.scientificnet.org:4567/commul/dspace/<my_image>:<my tag> -f Dockerfile.XX .
docker push gitlab.scientificnet.org:4567/commul/dspace/<my_image>:<my tag>
```

# Installation
## PostgreSQL
To install PostgreSQL, we need some passwords, so we need Kubernetes secrets

```console
$ kubectl -n dspace-dev create -f postgresql-secret.yaml 
secret "dspace-postgresql" created

$ kubectl -n dspace-dev get secrets
NAME                  TYPE                                  DATA      AGE
default-token-c1pd4   kubernetes.io/service-account-token   3         4d
dspace-postgresql     Opaque                                1         18s
```